/*-------------------------------------------------------------------------
  rtrack.h - header file for tracking content of registers on an mcs51

  Copyright 2007 Frieder Ferlemann (Frieder Ferlemann AT web.de)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
-------------------------------------------------------------------------*/

void rtrackUpdate (const char *line);

char * rtrackGetLit(const char *x);

int rtrackMoveALit (const char *x);

void rtrackLoadDptrWithSym (const char *x);
void rtrackLoadR0R1WithSym (const char *reg, const char *x);
